Documentation
¶
Index ¶
- Variables
- func CacheExpires(r *http.Response) time.Time
- func IsNil(i interface{}) bool
- func PtrBool(v bool) *bool
- func PtrFloat32(v float32) *float32
- func PtrFloat64(v float64) *float64
- func PtrInt(v int) *int
- func PtrInt32(v int32) *int32
- func PtrInt64(v int64) *int64
- func PtrString(v string) *string
- func PtrTime(v time.Time) *time.Time
- type APIClient
- type APIKey
- type APIResponse
- type ApiPublishEventRequest
- type BasicAuth
- type Configuration
- type EventAcceptedResponse
- func (o *EventAcceptedResponse) GetStatus() string
- func (o *EventAcceptedResponse) GetStatusOk() (*string, bool)
- func (o *EventAcceptedResponse) HasStatus() bool
- func (o EventAcceptedResponse) MarshalJSON() ([]byte, error)
- func (o *EventAcceptedResponse) SetStatus(v string)
- func (o EventAcceptedResponse) ToMap() (map[string]interface{}, error)
- type EventsAPIService
- type GenericOpenAPIError
- type MappedNullable
- type NullableBool
- type NullableEventAcceptedResponse
- func (v NullableEventAcceptedResponse) Get() *EventAcceptedResponse
- func (v NullableEventAcceptedResponse) IsSet() bool
- func (v NullableEventAcceptedResponse) MarshalJSON() ([]byte, error)
- func (v *NullableEventAcceptedResponse) Set(val *EventAcceptedResponse)
- func (v *NullableEventAcceptedResponse) UnmarshalJSON(src []byte) error
- func (v *NullableEventAcceptedResponse) Unset()
- type NullableFloat32
- type NullableFloat64
- type NullableInt
- type NullableInt32
- type NullableInt64
- type NullablePublishEventRequest
- func (v NullablePublishEventRequest) Get() *PublishEventRequest
- func (v NullablePublishEventRequest) IsSet() bool
- func (v NullablePublishEventRequest) MarshalJSON() ([]byte, error)
- func (v *NullablePublishEventRequest) Set(val *PublishEventRequest)
- func (v *NullablePublishEventRequest) UnmarshalJSON(src []byte) error
- func (v *NullablePublishEventRequest) Unset()
- type NullableString
- type NullableTime
- type PublishEventRequest
- func (o *PublishEventRequest) GetActorId() string
- func (o *PublishEventRequest) GetActorIdOk() (*string, bool)
- func (o *PublishEventRequest) GetClientName() string
- func (o *PublishEventRequest) GetClientNameOk() (*string, bool)
- func (o *PublishEventRequest) GetClientVersion() string
- func (o *PublishEventRequest) GetClientVersionOk() (*string, bool)
- func (o *PublishEventRequest) GetDuration() int32
- func (o *PublishEventRequest) GetDurationOk() (*int32, bool)
- func (o *PublishEventRequest) GetError() map[string]interface{}
- func (o *PublishEventRequest) GetErrorOk() (map[string]interface{}, bool)
- func (o *PublishEventRequest) GetEventId() string
- func (o *PublishEventRequest) GetEventIdOk() (*string, bool)
- func (o *PublishEventRequest) GetEventType() string
- func (o *PublishEventRequest) GetEventTypeOk() (*string, bool)
- func (o *PublishEventRequest) GetId() string
- func (o *PublishEventRequest) GetIdOk() (*string, bool)
- func (o *PublishEventRequest) GetIdentifyActorGivenId() string
- func (o *PublishEventRequest) GetIdentifyActorGivenIdOk() (*string, bool)
- func (o *PublishEventRequest) GetIdentifyActorName() string
- func (o *PublishEventRequest) GetIdentifyActorNameOk() (*string, bool)
- func (o *PublishEventRequest) GetIdentifyData() map[string]interface{}
- func (o *PublishEventRequest) GetIdentifyDataOk() (map[string]interface{}, bool)
- func (o *PublishEventRequest) GetIpAddress() string
- func (o *PublishEventRequest) GetIpAddressOk() (*string, bool)
- func (o *PublishEventRequest) GetIsError() bool
- func (o *PublishEventRequest) GetIsErrorOk() (*bool, bool)
- func (o *PublishEventRequest) GetMcpcatVersion() string
- func (o *PublishEventRequest) GetMcpcatVersionOk() (*string, bool)
- func (o *PublishEventRequest) GetParameters() map[string]interface{}
- func (o *PublishEventRequest) GetParametersOk() (map[string]interface{}, bool)
- func (o *PublishEventRequest) GetProjectId() string
- func (o *PublishEventRequest) GetProjectIdOk() (*string, bool)
- func (o *PublishEventRequest) GetProperties() map[string]interface{}
- func (o *PublishEventRequest) GetPropertiesOk() (map[string]interface{}, bool)
- func (o *PublishEventRequest) GetResourceName() string
- func (o *PublishEventRequest) GetResourceNameOk() (*string, bool)
- func (o *PublishEventRequest) GetResponse() map[string]interface{}
- func (o *PublishEventRequest) GetResponseOk() (map[string]interface{}, bool)
- func (o *PublishEventRequest) GetSdkLanguage() string
- func (o *PublishEventRequest) GetSdkLanguageOk() (*string, bool)
- func (o *PublishEventRequest) GetServerName() string
- func (o *PublishEventRequest) GetServerNameOk() (*string, bool)
- func (o *PublishEventRequest) GetServerVersion() string
- func (o *PublishEventRequest) GetServerVersionOk() (*string, bool)
- func (o *PublishEventRequest) GetSessionId() string
- func (o *PublishEventRequest) GetSessionIdOk() (*string, bool)
- func (o *PublishEventRequest) GetTags() map[string]string
- func (o *PublishEventRequest) GetTagsOk() (*map[string]string, bool)
- func (o *PublishEventRequest) GetTimestamp() time.Time
- func (o *PublishEventRequest) GetTimestampOk() (*time.Time, bool)
- func (o *PublishEventRequest) GetUserIntent() string
- func (o *PublishEventRequest) GetUserIntentOk() (*string, bool)
- func (o *PublishEventRequest) HasActorId() bool
- func (o *PublishEventRequest) HasClientName() bool
- func (o *PublishEventRequest) HasClientVersion() bool
- func (o *PublishEventRequest) HasDuration() bool
- func (o *PublishEventRequest) HasError() bool
- func (o *PublishEventRequest) HasEventId() bool
- func (o *PublishEventRequest) HasEventType() bool
- func (o *PublishEventRequest) HasId() bool
- func (o *PublishEventRequest) HasIdentifyActorGivenId() bool
- func (o *PublishEventRequest) HasIdentifyActorName() bool
- func (o *PublishEventRequest) HasIdentifyData() bool
- func (o *PublishEventRequest) HasIpAddress() bool
- func (o *PublishEventRequest) HasIsError() bool
- func (o *PublishEventRequest) HasMcpcatVersion() bool
- func (o *PublishEventRequest) HasParameters() bool
- func (o *PublishEventRequest) HasProjectId() bool
- func (o *PublishEventRequest) HasProperties() bool
- func (o *PublishEventRequest) HasResourceName() bool
- func (o *PublishEventRequest) HasResponse() bool
- func (o *PublishEventRequest) HasSdkLanguage() bool
- func (o *PublishEventRequest) HasServerName() bool
- func (o *PublishEventRequest) HasServerVersion() bool
- func (o *PublishEventRequest) HasTags() bool
- func (o *PublishEventRequest) HasTimestamp() bool
- func (o *PublishEventRequest) HasUserIntent() bool
- func (o PublishEventRequest) MarshalJSON() ([]byte, error)
- func (o *PublishEventRequest) SetActorId(v string)
- func (o *PublishEventRequest) SetClientName(v string)
- func (o *PublishEventRequest) SetClientVersion(v string)
- func (o *PublishEventRequest) SetDuration(v int32)
- func (o *PublishEventRequest) SetError(v map[string]interface{})
- func (o *PublishEventRequest) SetEventId(v string)
- func (o *PublishEventRequest) SetEventType(v string)
- func (o *PublishEventRequest) SetId(v string)
- func (o *PublishEventRequest) SetIdentifyActorGivenId(v string)
- func (o *PublishEventRequest) SetIdentifyActorName(v string)
- func (o *PublishEventRequest) SetIdentifyData(v map[string]interface{})
- func (o *PublishEventRequest) SetIpAddress(v string)
- func (o *PublishEventRequest) SetIsError(v bool)
- func (o *PublishEventRequest) SetMcpcatVersion(v string)
- func (o *PublishEventRequest) SetParameters(v map[string]interface{})
- func (o *PublishEventRequest) SetProjectId(v string)
- func (o *PublishEventRequest) SetProperties(v map[string]interface{})
- func (o *PublishEventRequest) SetResourceName(v string)
- func (o *PublishEventRequest) SetResponse(v map[string]interface{})
- func (o *PublishEventRequest) SetSdkLanguage(v string)
- func (o *PublishEventRequest) SetServerName(v string)
- func (o *PublishEventRequest) SetServerVersion(v string)
- func (o *PublishEventRequest) SetSessionId(v string)
- func (o *PublishEventRequest) SetTags(v map[string]string)
- func (o *PublishEventRequest) SetTimestamp(v time.Time)
- func (o *PublishEventRequest) SetUserIntent(v string)
- func (o PublishEventRequest) ToMap() (map[string]interface{}, error)
- func (o *PublishEventRequest) UnmarshalJSON(data []byte) (err error)
- type ServerConfiguration
- type ServerConfigurations
- type ServerVariable
Constants ¶
This section is empty.
Variables ¶
var ( JsonCheck = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?json)`) XmlCheck = regexp.MustCompile(`(?i:(?:application|text)/(?:[^;]+\+)?xml)`) )
var ( // ContextAPIKeys takes a string apikey as authentication for the request ContextAPIKeys = contextKey("apiKeys") // ContextServerIndex uses a server configuration from the index. ContextServerIndex = contextKey("serverIndex") // ContextOperationServerIndices uses a server configuration from the index mapping. ContextOperationServerIndices = contextKey("serverOperationIndices") // ContextServerVariables overrides a server configuration variables. ContextServerVariables = contextKey("serverVariables") // ContextOperationServerVariables overrides a server configuration variables using operation specific values. ContextOperationServerVariables = contextKey("serverOperationVariables") )
Functions ¶
func CacheExpires ¶
CacheExpires helper function to determine remaining time before repeating a request.
func PtrFloat32 ¶
PtrFloat32 is a helper routine that returns a pointer to given float value.
func PtrFloat64 ¶
PtrFloat64 is a helper routine that returns a pointer to given float value.
Types ¶
type APIClient ¶
type APIClient struct {
EventsAPI *EventsAPIService
// contains filtered or unexported fields
}
APIClient manages communication with the MCPCat API API vv1 In most cases there should be only one, shared, APIClient.
func NewAPIClient ¶
func NewAPIClient(cfg *Configuration) *APIClient
NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.
func (*APIClient) GetConfig ¶
func (c *APIClient) GetConfig() *Configuration
Allow modification of underlying config for alternate implementations and testing Caution: modifying the configuration while live can cause data races and potentially unwanted behavior
type APIKey ¶
APIKey provides API key based authentication to a request passed via context using ContextAPIKey
type APIResponse ¶
type APIResponse struct {
*http.Response `json:"-"`
Message string `json:"message,omitempty"`
// Operation is the name of the OpenAPI operation.
Operation string `json:"operation,omitempty"`
// RequestURL is the request URL. This value is always available, even if the
// embedded *http.Response is nil.
RequestURL string `json:"url,omitempty"`
// Method is the HTTP method used for the request. This value is always
// available, even if the embedded *http.Response is nil.
Method string `json:"method,omitempty"`
// Payload holds the contents of the response body (which may be nil or empty).
// This is provided here as the raw response.Body() reader will have already
// been drained.
Payload []byte `json:"-"`
}
APIResponse stores the API response returned by the server.
func NewAPIResponse ¶
func NewAPIResponse(r *http.Response) *APIResponse
NewAPIResponse returns a new APIResponse object.
func NewAPIResponseWithError ¶
func NewAPIResponseWithError(errorMessage string) *APIResponse
NewAPIResponseWithError returns a new APIResponse object with the provided error message.
type ApiPublishEventRequest ¶
type ApiPublishEventRequest struct {
ApiService *EventsAPIService
// contains filtered or unexported fields
}
func (ApiPublishEventRequest) Execute ¶
func (r ApiPublishEventRequest) Execute() (*EventAcceptedResponse, *http.Response, error)
func (ApiPublishEventRequest) PublishEventRequest ¶
func (r ApiPublishEventRequest) PublishEventRequest(publishEventRequest PublishEventRequest) ApiPublishEventRequest
type BasicAuth ¶
type BasicAuth struct {
UserName string `json:"userName,omitempty"`
Password string `json:"password,omitempty"`
}
BasicAuth provides basic http authentication to a request passed via context using ContextBasicAuth
type Configuration ¶
type Configuration struct {
Host string `json:"host,omitempty"`
Scheme string `json:"scheme,omitempty"`
DefaultHeader map[string]string `json:"defaultHeader,omitempty"`
UserAgent string `json:"userAgent,omitempty"`
Debug bool `json:"debug,omitempty"`
Servers ServerConfigurations
OperationServers map[string]ServerConfigurations
HTTPClient *http.Client
}
Configuration stores the configuration of the API client
func NewConfiguration ¶
func NewConfiguration() *Configuration
NewConfiguration returns a new Configuration object
func (*Configuration) AddDefaultHeader ¶
func (c *Configuration) AddDefaultHeader(key string, value string)
AddDefaultHeader adds a new HTTP header to the default header in the request
func (*Configuration) ServerURLWithContext ¶
ServerURLWithContext returns a new server URL given an endpoint
type EventAcceptedResponse ¶
type EventAcceptedResponse struct {
Status *string `json:"status,omitempty"`
}
EventAcceptedResponse struct for EventAcceptedResponse
func NewEventAcceptedResponse ¶
func NewEventAcceptedResponse() *EventAcceptedResponse
NewEventAcceptedResponse instantiates a new EventAcceptedResponse object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed
func NewEventAcceptedResponseWithDefaults ¶
func NewEventAcceptedResponseWithDefaults() *EventAcceptedResponse
NewEventAcceptedResponseWithDefaults instantiates a new EventAcceptedResponse object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set
func (*EventAcceptedResponse) GetStatus ¶
func (o *EventAcceptedResponse) GetStatus() string
GetStatus returns the Status field value if set, zero value otherwise.
func (*EventAcceptedResponse) GetStatusOk ¶
func (o *EventAcceptedResponse) GetStatusOk() (*string, bool)
GetStatusOk returns a tuple with the Status field value if set, nil otherwise and a boolean to check if the value has been set.
func (*EventAcceptedResponse) HasStatus ¶
func (o *EventAcceptedResponse) HasStatus() bool
HasStatus returns a boolean if a field has been set.
func (EventAcceptedResponse) MarshalJSON ¶
func (o EventAcceptedResponse) MarshalJSON() ([]byte, error)
func (*EventAcceptedResponse) SetStatus ¶
func (o *EventAcceptedResponse) SetStatus(v string)
SetStatus gets a reference to the given string and assigns it to the Status field.
func (EventAcceptedResponse) ToMap ¶
func (o EventAcceptedResponse) ToMap() (map[string]interface{}, error)
type EventsAPIService ¶
type EventsAPIService service
EventsAPIService EventsAPI service
func (*EventsAPIService) PublishEvent ¶
func (a *EventsAPIService) PublishEvent(ctx context.Context) ApiPublishEventRequest
PublishEvent Publish analytics event
Submit analytics events for a project. Returns immediately with 202 Accepted.
@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background(). @return ApiPublishEventRequest
func (*EventsAPIService) PublishEventExecute ¶
func (a *EventsAPIService) PublishEventExecute(r ApiPublishEventRequest) (*EventAcceptedResponse, *http.Response, error)
Execute executes the request
@return EventAcceptedResponse
type GenericOpenAPIError ¶
type GenericOpenAPIError struct {
// contains filtered or unexported fields
}
GenericOpenAPIError Provides access to the body, error and model on returned errors.
func (GenericOpenAPIError) Body ¶
func (e GenericOpenAPIError) Body() []byte
Body returns the raw bytes of the response
func (GenericOpenAPIError) Error ¶
func (e GenericOpenAPIError) Error() string
Error returns non-empty string if there was an error.
func (GenericOpenAPIError) Model ¶
func (e GenericOpenAPIError) Model() interface{}
Model returns the unpacked model of the error
type MappedNullable ¶
type NullableBool ¶
type NullableBool struct {
// contains filtered or unexported fields
}
func NewNullableBool ¶
func NewNullableBool(val *bool) *NullableBool
func (NullableBool) Get ¶
func (v NullableBool) Get() *bool
func (NullableBool) IsSet ¶
func (v NullableBool) IsSet() bool
func (NullableBool) MarshalJSON ¶
func (v NullableBool) MarshalJSON() ([]byte, error)
func (*NullableBool) Set ¶
func (v *NullableBool) Set(val *bool)
func (*NullableBool) UnmarshalJSON ¶
func (v *NullableBool) UnmarshalJSON(src []byte) error
func (*NullableBool) Unset ¶
func (v *NullableBool) Unset()
type NullableEventAcceptedResponse ¶
type NullableEventAcceptedResponse struct {
// contains filtered or unexported fields
}
func NewNullableEventAcceptedResponse ¶
func NewNullableEventAcceptedResponse(val *EventAcceptedResponse) *NullableEventAcceptedResponse
func (NullableEventAcceptedResponse) Get ¶
func (v NullableEventAcceptedResponse) Get() *EventAcceptedResponse
func (NullableEventAcceptedResponse) IsSet ¶
func (v NullableEventAcceptedResponse) IsSet() bool
func (NullableEventAcceptedResponse) MarshalJSON ¶
func (v NullableEventAcceptedResponse) MarshalJSON() ([]byte, error)
func (*NullableEventAcceptedResponse) Set ¶
func (v *NullableEventAcceptedResponse) Set(val *EventAcceptedResponse)
func (*NullableEventAcceptedResponse) UnmarshalJSON ¶
func (v *NullableEventAcceptedResponse) UnmarshalJSON(src []byte) error
func (*NullableEventAcceptedResponse) Unset ¶
func (v *NullableEventAcceptedResponse) Unset()
type NullableFloat32 ¶
type NullableFloat32 struct {
// contains filtered or unexported fields
}
func NewNullableFloat32 ¶
func NewNullableFloat32(val *float32) *NullableFloat32
func (NullableFloat32) Get ¶
func (v NullableFloat32) Get() *float32
func (NullableFloat32) IsSet ¶
func (v NullableFloat32) IsSet() bool
func (NullableFloat32) MarshalJSON ¶
func (v NullableFloat32) MarshalJSON() ([]byte, error)
func (*NullableFloat32) Set ¶
func (v *NullableFloat32) Set(val *float32)
func (*NullableFloat32) UnmarshalJSON ¶
func (v *NullableFloat32) UnmarshalJSON(src []byte) error
func (*NullableFloat32) Unset ¶
func (v *NullableFloat32) Unset()
type NullableFloat64 ¶
type NullableFloat64 struct {
// contains filtered or unexported fields
}
func NewNullableFloat64 ¶
func NewNullableFloat64(val *float64) *NullableFloat64
func (NullableFloat64) Get ¶
func (v NullableFloat64) Get() *float64
func (NullableFloat64) IsSet ¶
func (v NullableFloat64) IsSet() bool
func (NullableFloat64) MarshalJSON ¶
func (v NullableFloat64) MarshalJSON() ([]byte, error)
func (*NullableFloat64) Set ¶
func (v *NullableFloat64) Set(val *float64)
func (*NullableFloat64) UnmarshalJSON ¶
func (v *NullableFloat64) UnmarshalJSON(src []byte) error
func (*NullableFloat64) Unset ¶
func (v *NullableFloat64) Unset()
type NullableInt ¶
type NullableInt struct {
// contains filtered or unexported fields
}
func NewNullableInt ¶
func NewNullableInt(val *int) *NullableInt
func (NullableInt) Get ¶
func (v NullableInt) Get() *int
func (NullableInt) IsSet ¶
func (v NullableInt) IsSet() bool
func (NullableInt) MarshalJSON ¶
func (v NullableInt) MarshalJSON() ([]byte, error)
func (*NullableInt) Set ¶
func (v *NullableInt) Set(val *int)
func (*NullableInt) UnmarshalJSON ¶
func (v *NullableInt) UnmarshalJSON(src []byte) error
func (*NullableInt) Unset ¶
func (v *NullableInt) Unset()
type NullableInt32 ¶
type NullableInt32 struct {
// contains filtered or unexported fields
}
func NewNullableInt32 ¶
func NewNullableInt32(val *int32) *NullableInt32
func (NullableInt32) Get ¶
func (v NullableInt32) Get() *int32
func (NullableInt32) IsSet ¶
func (v NullableInt32) IsSet() bool
func (NullableInt32) MarshalJSON ¶
func (v NullableInt32) MarshalJSON() ([]byte, error)
func (*NullableInt32) Set ¶
func (v *NullableInt32) Set(val *int32)
func (*NullableInt32) UnmarshalJSON ¶
func (v *NullableInt32) UnmarshalJSON(src []byte) error
func (*NullableInt32) Unset ¶
func (v *NullableInt32) Unset()
type NullableInt64 ¶
type NullableInt64 struct {
// contains filtered or unexported fields
}
func NewNullableInt64 ¶
func NewNullableInt64(val *int64) *NullableInt64
func (NullableInt64) Get ¶
func (v NullableInt64) Get() *int64
func (NullableInt64) IsSet ¶
func (v NullableInt64) IsSet() bool
func (NullableInt64) MarshalJSON ¶
func (v NullableInt64) MarshalJSON() ([]byte, error)
func (*NullableInt64) Set ¶
func (v *NullableInt64) Set(val *int64)
func (*NullableInt64) UnmarshalJSON ¶
func (v *NullableInt64) UnmarshalJSON(src []byte) error
func (*NullableInt64) Unset ¶
func (v *NullableInt64) Unset()
type NullablePublishEventRequest ¶
type NullablePublishEventRequest struct {
// contains filtered or unexported fields
}
func NewNullablePublishEventRequest ¶
func NewNullablePublishEventRequest(val *PublishEventRequest) *NullablePublishEventRequest
func (NullablePublishEventRequest) Get ¶
func (v NullablePublishEventRequest) Get() *PublishEventRequest
func (NullablePublishEventRequest) IsSet ¶
func (v NullablePublishEventRequest) IsSet() bool
func (NullablePublishEventRequest) MarshalJSON ¶
func (v NullablePublishEventRequest) MarshalJSON() ([]byte, error)
func (*NullablePublishEventRequest) Set ¶
func (v *NullablePublishEventRequest) Set(val *PublishEventRequest)
func (*NullablePublishEventRequest) UnmarshalJSON ¶
func (v *NullablePublishEventRequest) UnmarshalJSON(src []byte) error
func (*NullablePublishEventRequest) Unset ¶
func (v *NullablePublishEventRequest) Unset()
type NullableString ¶
type NullableString struct {
// contains filtered or unexported fields
}
func NewNullableString ¶
func NewNullableString(val *string) *NullableString
func (NullableString) Get ¶
func (v NullableString) Get() *string
func (NullableString) IsSet ¶
func (v NullableString) IsSet() bool
func (NullableString) MarshalJSON ¶
func (v NullableString) MarshalJSON() ([]byte, error)
func (*NullableString) Set ¶
func (v *NullableString) Set(val *string)
func (*NullableString) UnmarshalJSON ¶
func (v *NullableString) UnmarshalJSON(src []byte) error
func (*NullableString) Unset ¶
func (v *NullableString) Unset()
type NullableTime ¶
type NullableTime struct {
// contains filtered or unexported fields
}
func NewNullableTime ¶
func NewNullableTime(val *time.Time) *NullableTime
func (NullableTime) Get ¶
func (v NullableTime) Get() *time.Time
func (NullableTime) IsSet ¶
func (v NullableTime) IsSet() bool
func (NullableTime) MarshalJSON ¶
func (v NullableTime) MarshalJSON() ([]byte, error)
func (*NullableTime) Set ¶
func (v *NullableTime) Set(val *time.Time)
func (*NullableTime) UnmarshalJSON ¶
func (v *NullableTime) UnmarshalJSON(src []byte) error
func (*NullableTime) Unset ¶
func (v *NullableTime) Unset()
type PublishEventRequest ¶
type PublishEventRequest struct {
// ID of the event, typically auto-generated by the MCPCat Agent
Id *string `json:"id,omitempty"`
// ID of the project this event belongs to
ProjectId *string `json:"project_id,omitempty"`
// ID of the session this event belongs to
SessionId string `json:"session_id"`
// Optional actor ID
ActorId *string `json:"actor_id,omitempty"`
// Optional custom event ID (must be unique)
EventId *string `json:"event_id,omitempty"`
// Type of event (e.g., mcp:tools/call, mcpcat:identify)
EventType *string `json:"event_type,omitempty"`
// Whether this event represents an error
IsError *bool `json:"is_error,omitempty"`
// Error details if is_error is true
Error map[string]interface{} `json:"error,omitempty"`
// Name of the resource accessed (for resource events)
ResourceName *string `json:"resource_name,omitempty"`
// Duration of the operation in milliseconds
Duration *int32 `json:"duration,omitempty"`
// Agent-provided timestamp of when the event occurred
Timestamp *time.Time `json:"timestamp,omitempty"`
// Captured explanation of why the actor made this request
UserIntent *string `json:"user_intent,omitempty"`
// Parameters sent with the request
Parameters map[string]interface{} `json:"parameters,omitempty"`
// Response data from the operation
Response map[string]interface{} `json:"response,omitempty"`
// Actor ID for mcpcat:identify events
IdentifyActorGivenId *string `json:"identify_actor_given_id,omitempty"`
// Actor name for mcpcat:identify events
IdentifyActorName *string `json:"identify_actor_name,omitempty"`
// Additional data for mcpcat:identify events
IdentifyData map[string]interface{} `json:"identify_data,omitempty"`
// Custom string key-value pairs. Keys: max 32 chars, alphanumeric/underscore/period/colon/dash only. Values: max 200 chars, no newlines. Max 50 entries.
Tags *map[string]string `json:"tags,omitempty"`
// Custom structured data. Keys are strings, values can be string, number, boolean, array, object, or null (null values are filtered out).
Properties map[string]interface{} `json:"properties,omitempty"`
// IP address of the client
IpAddress *string `json:"ip_address,omitempty"`
// Programming language of the SDK used
SdkLanguage *string `json:"sdk_language,omitempty"`
// Version of MCPCat being used
McpcatVersion *string `json:"mcpcat_version,omitempty"`
// Name of the MCP server
ServerName *string `json:"server_name,omitempty"`
// Version of the MCP server
ServerVersion *string `json:"server_version,omitempty"`
// Name of the MCP client
ClientName *string `json:"client_name,omitempty"`
// Version of the MCP client
ClientVersion *string `json:"client_version,omitempty"`
AdditionalProperties map[string]interface{}
}
PublishEventRequest struct for PublishEventRequest
func NewPublishEventRequest ¶
func NewPublishEventRequest(sessionId string) *PublishEventRequest
NewPublishEventRequest instantiates a new PublishEventRequest object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed
func NewPublishEventRequestWithDefaults ¶
func NewPublishEventRequestWithDefaults() *PublishEventRequest
NewPublishEventRequestWithDefaults instantiates a new PublishEventRequest object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set
func (*PublishEventRequest) GetActorId ¶
func (o *PublishEventRequest) GetActorId() string
GetActorId returns the ActorId field value if set, zero value otherwise.
func (*PublishEventRequest) GetActorIdOk ¶
func (o *PublishEventRequest) GetActorIdOk() (*string, bool)
GetActorIdOk returns a tuple with the ActorId field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetClientName ¶
func (o *PublishEventRequest) GetClientName() string
GetClientName returns the ClientName field value if set, zero value otherwise.
func (*PublishEventRequest) GetClientNameOk ¶
func (o *PublishEventRequest) GetClientNameOk() (*string, bool)
GetClientNameOk returns a tuple with the ClientName field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetClientVersion ¶
func (o *PublishEventRequest) GetClientVersion() string
GetClientVersion returns the ClientVersion field value if set, zero value otherwise.
func (*PublishEventRequest) GetClientVersionOk ¶
func (o *PublishEventRequest) GetClientVersionOk() (*string, bool)
GetClientVersionOk returns a tuple with the ClientVersion field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetDuration ¶
func (o *PublishEventRequest) GetDuration() int32
GetDuration returns the Duration field value if set, zero value otherwise.
func (*PublishEventRequest) GetDurationOk ¶
func (o *PublishEventRequest) GetDurationOk() (*int32, bool)
GetDurationOk returns a tuple with the Duration field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetError ¶
func (o *PublishEventRequest) GetError() map[string]interface{}
GetError returns the Error field value if set, zero value otherwise.
func (*PublishEventRequest) GetErrorOk ¶
func (o *PublishEventRequest) GetErrorOk() (map[string]interface{}, bool)
GetErrorOk returns a tuple with the Error field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetEventId ¶
func (o *PublishEventRequest) GetEventId() string
GetEventId returns the EventId field value if set, zero value otherwise.
func (*PublishEventRequest) GetEventIdOk ¶
func (o *PublishEventRequest) GetEventIdOk() (*string, bool)
GetEventIdOk returns a tuple with the EventId field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetEventType ¶
func (o *PublishEventRequest) GetEventType() string
GetEventType returns the EventType field value if set, zero value otherwise.
func (*PublishEventRequest) GetEventTypeOk ¶
func (o *PublishEventRequest) GetEventTypeOk() (*string, bool)
GetEventTypeOk returns a tuple with the EventType field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetId ¶
func (o *PublishEventRequest) GetId() string
GetId returns the Id field value if set, zero value otherwise.
func (*PublishEventRequest) GetIdOk ¶
func (o *PublishEventRequest) GetIdOk() (*string, bool)
GetIdOk returns a tuple with the Id field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetIdentifyActorGivenId ¶
func (o *PublishEventRequest) GetIdentifyActorGivenId() string
GetIdentifyActorGivenId returns the IdentifyActorGivenId field value if set, zero value otherwise.
func (*PublishEventRequest) GetIdentifyActorGivenIdOk ¶
func (o *PublishEventRequest) GetIdentifyActorGivenIdOk() (*string, bool)
GetIdentifyActorGivenIdOk returns a tuple with the IdentifyActorGivenId field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetIdentifyActorName ¶
func (o *PublishEventRequest) GetIdentifyActorName() string
GetIdentifyActorName returns the IdentifyActorName field value if set, zero value otherwise.
func (*PublishEventRequest) GetIdentifyActorNameOk ¶
func (o *PublishEventRequest) GetIdentifyActorNameOk() (*string, bool)
GetIdentifyActorNameOk returns a tuple with the IdentifyActorName field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetIdentifyData ¶
func (o *PublishEventRequest) GetIdentifyData() map[string]interface{}
GetIdentifyData returns the IdentifyData field value if set, zero value otherwise.
func (*PublishEventRequest) GetIdentifyDataOk ¶
func (o *PublishEventRequest) GetIdentifyDataOk() (map[string]interface{}, bool)
GetIdentifyDataOk returns a tuple with the IdentifyData field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetIpAddress ¶
func (o *PublishEventRequest) GetIpAddress() string
GetIpAddress returns the IpAddress field value if set, zero value otherwise.
func (*PublishEventRequest) GetIpAddressOk ¶
func (o *PublishEventRequest) GetIpAddressOk() (*string, bool)
GetIpAddressOk returns a tuple with the IpAddress field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetIsError ¶
func (o *PublishEventRequest) GetIsError() bool
GetIsError returns the IsError field value if set, zero value otherwise.
func (*PublishEventRequest) GetIsErrorOk ¶
func (o *PublishEventRequest) GetIsErrorOk() (*bool, bool)
GetIsErrorOk returns a tuple with the IsError field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetMcpcatVersion ¶
func (o *PublishEventRequest) GetMcpcatVersion() string
GetMcpcatVersion returns the McpcatVersion field value if set, zero value otherwise.
func (*PublishEventRequest) GetMcpcatVersionOk ¶
func (o *PublishEventRequest) GetMcpcatVersionOk() (*string, bool)
GetMcpcatVersionOk returns a tuple with the McpcatVersion field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetParameters ¶
func (o *PublishEventRequest) GetParameters() map[string]interface{}
GetParameters returns the Parameters field value if set, zero value otherwise.
func (*PublishEventRequest) GetParametersOk ¶
func (o *PublishEventRequest) GetParametersOk() (map[string]interface{}, bool)
GetParametersOk returns a tuple with the Parameters field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetProjectId ¶
func (o *PublishEventRequest) GetProjectId() string
GetProjectId returns the ProjectId field value if set, zero value otherwise.
func (*PublishEventRequest) GetProjectIdOk ¶
func (o *PublishEventRequest) GetProjectIdOk() (*string, bool)
GetProjectIdOk returns a tuple with the ProjectId field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetProperties ¶
func (o *PublishEventRequest) GetProperties() map[string]interface{}
GetProperties returns the Properties field value if set, zero value otherwise.
func (*PublishEventRequest) GetPropertiesOk ¶
func (o *PublishEventRequest) GetPropertiesOk() (map[string]interface{}, bool)
GetPropertiesOk returns a tuple with the Properties field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetResourceName ¶
func (o *PublishEventRequest) GetResourceName() string
GetResourceName returns the ResourceName field value if set, zero value otherwise.
func (*PublishEventRequest) GetResourceNameOk ¶
func (o *PublishEventRequest) GetResourceNameOk() (*string, bool)
GetResourceNameOk returns a tuple with the ResourceName field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetResponse ¶
func (o *PublishEventRequest) GetResponse() map[string]interface{}
GetResponse returns the Response field value if set, zero value otherwise.
func (*PublishEventRequest) GetResponseOk ¶
func (o *PublishEventRequest) GetResponseOk() (map[string]interface{}, bool)
GetResponseOk returns a tuple with the Response field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetSdkLanguage ¶
func (o *PublishEventRequest) GetSdkLanguage() string
GetSdkLanguage returns the SdkLanguage field value if set, zero value otherwise.
func (*PublishEventRequest) GetSdkLanguageOk ¶
func (o *PublishEventRequest) GetSdkLanguageOk() (*string, bool)
GetSdkLanguageOk returns a tuple with the SdkLanguage field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetServerName ¶
func (o *PublishEventRequest) GetServerName() string
GetServerName returns the ServerName field value if set, zero value otherwise.
func (*PublishEventRequest) GetServerNameOk ¶
func (o *PublishEventRequest) GetServerNameOk() (*string, bool)
GetServerNameOk returns a tuple with the ServerName field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetServerVersion ¶
func (o *PublishEventRequest) GetServerVersion() string
GetServerVersion returns the ServerVersion field value if set, zero value otherwise.
func (*PublishEventRequest) GetServerVersionOk ¶
func (o *PublishEventRequest) GetServerVersionOk() (*string, bool)
GetServerVersionOk returns a tuple with the ServerVersion field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetSessionId ¶
func (o *PublishEventRequest) GetSessionId() string
GetSessionId returns the SessionId field value
func (*PublishEventRequest) GetSessionIdOk ¶
func (o *PublishEventRequest) GetSessionIdOk() (*string, bool)
GetSessionIdOk returns a tuple with the SessionId field value and a boolean to check if the value has been set.
func (*PublishEventRequest) GetTags ¶
func (o *PublishEventRequest) GetTags() map[string]string
GetTags returns the Tags field value if set, zero value otherwise.
func (*PublishEventRequest) GetTagsOk ¶
func (o *PublishEventRequest) GetTagsOk() (*map[string]string, bool)
GetTagsOk returns a tuple with the Tags field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetTimestamp ¶
func (o *PublishEventRequest) GetTimestamp() time.Time
GetTimestamp returns the Timestamp field value if set, zero value otherwise.
func (*PublishEventRequest) GetTimestampOk ¶
func (o *PublishEventRequest) GetTimestampOk() (*time.Time, bool)
GetTimestampOk returns a tuple with the Timestamp field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) GetUserIntent ¶
func (o *PublishEventRequest) GetUserIntent() string
GetUserIntent returns the UserIntent field value if set, zero value otherwise.
func (*PublishEventRequest) GetUserIntentOk ¶
func (o *PublishEventRequest) GetUserIntentOk() (*string, bool)
GetUserIntentOk returns a tuple with the UserIntent field value if set, nil otherwise and a boolean to check if the value has been set.
func (*PublishEventRequest) HasActorId ¶
func (o *PublishEventRequest) HasActorId() bool
HasActorId returns a boolean if a field has been set.
func (*PublishEventRequest) HasClientName ¶
func (o *PublishEventRequest) HasClientName() bool
HasClientName returns a boolean if a field has been set.
func (*PublishEventRequest) HasClientVersion ¶
func (o *PublishEventRequest) HasClientVersion() bool
HasClientVersion returns a boolean if a field has been set.
func (*PublishEventRequest) HasDuration ¶
func (o *PublishEventRequest) HasDuration() bool
HasDuration returns a boolean if a field has been set.
func (*PublishEventRequest) HasError ¶
func (o *PublishEventRequest) HasError() bool
HasError returns a boolean if a field has been set.
func (*PublishEventRequest) HasEventId ¶
func (o *PublishEventRequest) HasEventId() bool
HasEventId returns a boolean if a field has been set.
func (*PublishEventRequest) HasEventType ¶
func (o *PublishEventRequest) HasEventType() bool
HasEventType returns a boolean if a field has been set.
func (*PublishEventRequest) HasId ¶
func (o *PublishEventRequest) HasId() bool
HasId returns a boolean if a field has been set.
func (*PublishEventRequest) HasIdentifyActorGivenId ¶
func (o *PublishEventRequest) HasIdentifyActorGivenId() bool
HasIdentifyActorGivenId returns a boolean if a field has been set.
func (*PublishEventRequest) HasIdentifyActorName ¶
func (o *PublishEventRequest) HasIdentifyActorName() bool
HasIdentifyActorName returns a boolean if a field has been set.
func (*PublishEventRequest) HasIdentifyData ¶
func (o *PublishEventRequest) HasIdentifyData() bool
HasIdentifyData returns a boolean if a field has been set.
func (*PublishEventRequest) HasIpAddress ¶
func (o *PublishEventRequest) HasIpAddress() bool
HasIpAddress returns a boolean if a field has been set.
func (*PublishEventRequest) HasIsError ¶
func (o *PublishEventRequest) HasIsError() bool
HasIsError returns a boolean if a field has been set.
func (*PublishEventRequest) HasMcpcatVersion ¶
func (o *PublishEventRequest) HasMcpcatVersion() bool
HasMcpcatVersion returns a boolean if a field has been set.
func (*PublishEventRequest) HasParameters ¶
func (o *PublishEventRequest) HasParameters() bool
HasParameters returns a boolean if a field has been set.
func (*PublishEventRequest) HasProjectId ¶
func (o *PublishEventRequest) HasProjectId() bool
HasProjectId returns a boolean if a field has been set.
func (*PublishEventRequest) HasProperties ¶
func (o *PublishEventRequest) HasProperties() bool
HasProperties returns a boolean if a field has been set.
func (*PublishEventRequest) HasResourceName ¶
func (o *PublishEventRequest) HasResourceName() bool
HasResourceName returns a boolean if a field has been set.
func (*PublishEventRequest) HasResponse ¶
func (o *PublishEventRequest) HasResponse() bool
HasResponse returns a boolean if a field has been set.
func (*PublishEventRequest) HasSdkLanguage ¶
func (o *PublishEventRequest) HasSdkLanguage() bool
HasSdkLanguage returns a boolean if a field has been set.
func (*PublishEventRequest) HasServerName ¶
func (o *PublishEventRequest) HasServerName() bool
HasServerName returns a boolean if a field has been set.
func (*PublishEventRequest) HasServerVersion ¶
func (o *PublishEventRequest) HasServerVersion() bool
HasServerVersion returns a boolean if a field has been set.
func (*PublishEventRequest) HasTags ¶
func (o *PublishEventRequest) HasTags() bool
HasTags returns a boolean if a field has been set.
func (*PublishEventRequest) HasTimestamp ¶
func (o *PublishEventRequest) HasTimestamp() bool
HasTimestamp returns a boolean if a field has been set.
func (*PublishEventRequest) HasUserIntent ¶
func (o *PublishEventRequest) HasUserIntent() bool
HasUserIntent returns a boolean if a field has been set.
func (PublishEventRequest) MarshalJSON ¶
func (o PublishEventRequest) MarshalJSON() ([]byte, error)
func (*PublishEventRequest) SetActorId ¶
func (o *PublishEventRequest) SetActorId(v string)
SetActorId gets a reference to the given string and assigns it to the ActorId field.
func (*PublishEventRequest) SetClientName ¶
func (o *PublishEventRequest) SetClientName(v string)
SetClientName gets a reference to the given string and assigns it to the ClientName field.
func (*PublishEventRequest) SetClientVersion ¶
func (o *PublishEventRequest) SetClientVersion(v string)
SetClientVersion gets a reference to the given string and assigns it to the ClientVersion field.
func (*PublishEventRequest) SetDuration ¶
func (o *PublishEventRequest) SetDuration(v int32)
SetDuration gets a reference to the given int32 and assigns it to the Duration field.
func (*PublishEventRequest) SetError ¶
func (o *PublishEventRequest) SetError(v map[string]interface{})
SetError gets a reference to the given map[string]interface{} and assigns it to the Error field.
func (*PublishEventRequest) SetEventId ¶
func (o *PublishEventRequest) SetEventId(v string)
SetEventId gets a reference to the given string and assigns it to the EventId field.
func (*PublishEventRequest) SetEventType ¶
func (o *PublishEventRequest) SetEventType(v string)
SetEventType gets a reference to the given string and assigns it to the EventType field.
func (*PublishEventRequest) SetId ¶
func (o *PublishEventRequest) SetId(v string)
SetId gets a reference to the given string and assigns it to the Id field.
func (*PublishEventRequest) SetIdentifyActorGivenId ¶
func (o *PublishEventRequest) SetIdentifyActorGivenId(v string)
SetIdentifyActorGivenId gets a reference to the given string and assigns it to the IdentifyActorGivenId field.
func (*PublishEventRequest) SetIdentifyActorName ¶
func (o *PublishEventRequest) SetIdentifyActorName(v string)
SetIdentifyActorName gets a reference to the given string and assigns it to the IdentifyActorName field.
func (*PublishEventRequest) SetIdentifyData ¶
func (o *PublishEventRequest) SetIdentifyData(v map[string]interface{})
SetIdentifyData gets a reference to the given map[string]interface{} and assigns it to the IdentifyData field.
func (*PublishEventRequest) SetIpAddress ¶
func (o *PublishEventRequest) SetIpAddress(v string)
SetIpAddress gets a reference to the given string and assigns it to the IpAddress field.
func (*PublishEventRequest) SetIsError ¶
func (o *PublishEventRequest) SetIsError(v bool)
SetIsError gets a reference to the given bool and assigns it to the IsError field.
func (*PublishEventRequest) SetMcpcatVersion ¶
func (o *PublishEventRequest) SetMcpcatVersion(v string)
SetMcpcatVersion gets a reference to the given string and assigns it to the McpcatVersion field.
func (*PublishEventRequest) SetParameters ¶
func (o *PublishEventRequest) SetParameters(v map[string]interface{})
SetParameters gets a reference to the given map[string]interface{} and assigns it to the Parameters field.
func (*PublishEventRequest) SetProjectId ¶
func (o *PublishEventRequest) SetProjectId(v string)
SetProjectId gets a reference to the given string and assigns it to the ProjectId field.
func (*PublishEventRequest) SetProperties ¶
func (o *PublishEventRequest) SetProperties(v map[string]interface{})
SetProperties gets a reference to the given map[string]interface{} and assigns it to the Properties field.
func (*PublishEventRequest) SetResourceName ¶
func (o *PublishEventRequest) SetResourceName(v string)
SetResourceName gets a reference to the given string and assigns it to the ResourceName field.
func (*PublishEventRequest) SetResponse ¶
func (o *PublishEventRequest) SetResponse(v map[string]interface{})
SetResponse gets a reference to the given map[string]interface{} and assigns it to the Response field.
func (*PublishEventRequest) SetSdkLanguage ¶
func (o *PublishEventRequest) SetSdkLanguage(v string)
SetSdkLanguage gets a reference to the given string and assigns it to the SdkLanguage field.
func (*PublishEventRequest) SetServerName ¶
func (o *PublishEventRequest) SetServerName(v string)
SetServerName gets a reference to the given string and assigns it to the ServerName field.
func (*PublishEventRequest) SetServerVersion ¶
func (o *PublishEventRequest) SetServerVersion(v string)
SetServerVersion gets a reference to the given string and assigns it to the ServerVersion field.
func (*PublishEventRequest) SetSessionId ¶
func (o *PublishEventRequest) SetSessionId(v string)
SetSessionId sets field value
func (*PublishEventRequest) SetTags ¶
func (o *PublishEventRequest) SetTags(v map[string]string)
SetTags gets a reference to the given map[string]string and assigns it to the Tags field.
func (*PublishEventRequest) SetTimestamp ¶
func (o *PublishEventRequest) SetTimestamp(v time.Time)
SetTimestamp gets a reference to the given time.Time and assigns it to the Timestamp field.
func (*PublishEventRequest) SetUserIntent ¶
func (o *PublishEventRequest) SetUserIntent(v string)
SetUserIntent gets a reference to the given string and assigns it to the UserIntent field.
func (PublishEventRequest) ToMap ¶
func (o PublishEventRequest) ToMap() (map[string]interface{}, error)
func (*PublishEventRequest) UnmarshalJSON ¶
func (o *PublishEventRequest) UnmarshalJSON(data []byte) (err error)
type ServerConfiguration ¶
type ServerConfiguration struct {
URL string
Description string
Variables map[string]ServerVariable
}
ServerConfiguration stores the information about a server
type ServerConfigurations ¶
type ServerConfigurations []ServerConfiguration
ServerConfigurations stores multiple ServerConfiguration items
type ServerVariable ¶
ServerVariable stores the information about a server variable